# ZQL 

- A pure Python implementation of the Gen Z Query Language.
- Currently supports a subset of ANSI SQL.
- Can convert ZQL to SQLite and SQLite to ZQL for some queries.
- Visit genzql.com to try it out!

## Grammar

See `genzql/zql_grammar.tmjd`.

## Contributors

- Vinesh Kannan
- Tamjid Rahman
